@@ -4,12 +4,29 @@ from cro_validate.enum import DataType
 
 
 def get(definition_or_name):
-	'''returns :ref:`Definition` instance.
-	'''
+	"""
+	Returns the :ref:`Definition` instance representing this definition. Use the
+	returned Definition to retrieve all meta for this definition
+	(name, data_type, etc.). Raises input error if Definition is not found.
+
+	:param str definition_or_name: Definition name to retrieve from the global index.
+	For convenience, the Definition instance itself may be passed.
+	:return: The Definition instance loaded.
+	:rtype: Definition
+	:raises: Input error if definition not found.
+	"""
 	return Definitions.Index.get(definition_or_name)
 
 
 def exists(name):
+	"""
+	Returns True if the name is indexed, otherwise False.
+
+	:param str name: Definition name to verify.
+	:return: True if name exists, otherwise False.
+	:rtype: bool
+	:exception: Input error if definition not found.
+	"""
 	return Definitions.Index.exists(name)
 
 
@@ -45,8 +62,7 @@ def register_definition(
 			deprecated=Utils.Empty,
 			internal=Utils.Empty,
 			rules=Utils.Empty,
-			meta=Utils.Empty,
-			dependency_resolver=Utils.Empty
+			meta=Utils.Empty
 		):
 	result = Definitions.Index.register_definition(
 			name=name,
@@ -60,8 +76,7 @@ def register_definition(
 			deprecated=deprecated,
 			internal=internal,
 			rules=rules,
-			meta=meta,
-			dependency_resolver=dependency_resolver
+			meta=meta
 		)
 	return result
 
@@ -82,7 +97,7 @@ def list_dependent_definitions(definition_name):
 
 def list_fields(name_or_definition):
 	definition = name_or_definition
-	if not isinstance(definition, Definitions.Definition):		
+	if not isinstance(definition, Definitions.Definition):
 		definition = get(str(name_or_definition))
 	return definition.list_fields()
 
@@ -92,7 +107,6 @@ def validate_input(
 			value,
 			field_fqn=None,
 			field_name=None,
-			dependent_values={},
 			**rules_kw
 		):
 	results = Definitions.Index.validate_input(
@@ -101,11 +115,10 @@ def validate_input(
 			field_name,
 			definition_or_name,
 			value,
-			dependent_values,
 			**rules_kw
 		)
 	return results
 
 
 def clear():
-	Definitions.Index.clear()
\ No newline at end of file
+	Definitions.Index.clear()
