@@ -3,6 +3,7 @@ import json
 import cro_validate.classes.definition_classes as Definitions
 from cro_validate.classes.configuration_classes import Config
 from cro_validate.enum import DataType
+from cro_validate.classes.util_classes import Empty, Omitted
 
 
 class DefaultExamplesProvider:
@@ -27,15 +28,6 @@ class DefaultExamplesProvider:
 		#	return ['9f34f340-54d2-4403-a53b-d8017a64734f']
 		#return None
 
-class _Empty:
-	pass
-
-
-def isempty(v):
-	if isinstance(v, _Empty):
-		return True
-	return False
-
 
 class PrimitiveValueGenerator:
 	def __init__(self, name, definition, values):
@@ -55,14 +47,14 @@ class PrimitiveValueGenerator:
 			next_value = self.values[self.index]
 			self.index = self.index + 1
 			return next_value
-		return _Empty()
+		return Empty()
 
 	def __iter__(self):
 		return self
 
 	def __next__(self):
 		result = self.next()
-		if isempty(result):
+		if Empty.isempty(result):
 			raise StopIteration()
 		return result
 
@@ -77,32 +69,35 @@ class ObjectValueGenerator:
 		self.generators = {}
 		self.seen = set()
 		self.processed = set()
-		self.selected = _Empty()
-		for k in definition.validator.list_field_names():
-			field_definition = Definitions.Index.get(definition.validator.get_field_definition_name(k))
+		self.selected = Empty()
+		fields = definition.list_fields()
+		for k in fields:
+			field = fields[k]
+			field_definition = Definitions.Index.get(field.definition_name)
 			given_values = []
-			if k in values:
-				given_values = values[k]
-			elif not definition.validator.is_field_required(k):
+			if field.input_name in values:
+				given_values = values[field.input_name]
+			elif not field.required:
 				continue
 			else:
-				raise Config.exception_factory.create_internal_error(k, 'Required field missing examples.' + str(values) + ' ' + field_name)
+				msg = 'Required field missing examples (values=' + str(values) + ', field_name=' + field_name + ').'
+				raise Config.exception_factory.create_internal_error(k, msg)
 			if field_definition.data_type == DataType.Object:
-				self.generators[k] = ObjectValueGenerator(k, field_definition, given_values)
+				self.generators[field.input_name] = ObjectValueGenerator(field.input_name, field_definition, given_values)
 			elif field_definition.data_type == DataType.Array:
-				self.generators[k] = ArrayGenerator(k, field_definition, given_values)
+				self.generators[field.input_name] = ArrayGenerator(field.input_name, field_definition, given_values)
 			else:
-				self.generators[k] = PrimitiveValueGenerator(k, field_definition, given_values)
+				self.generators[field.input_name] = PrimitiveValueGenerator(field.input_name, field_definition, given_values)
 		self.first_value = self.next()
 
 	def first(self):
-		if not isinstance(self.first_value, _Empty):
+		if not isinstance(self.first_value, Empty):
 			return self.first_value
 		self.first_value = self.next()
 		return self.first_value
 
 	def _select_next(self):
-		selected = _Empty()
+		selected = Empty()
 		for k in self.generators:
 			if k in self.processed:
 				continue
@@ -114,19 +109,21 @@ class ObjectValueGenerator:
 	def next(self):
 		result = {}
 		first = False
-		if isempty(self.selected):
+		if Empty.isempty(self.selected):
 			first = True
 			self.selected = self._select_next()
-		if isempty(self.selected):
-			return _Empty()
+		if Empty.isempty(self.selected):
+			return Empty()
 		for k in self.generators:
 			if first is False and k == self.selected:
-				result[k] = self.generators[self.selected].next()
-				if isempty(result[k]):
-					self.selected = _Empty()
+				v = self.generators[self.selected].next()
+				if Empty.isempty(v):
+					self.selected = Empty()
 					return self.next()
 			else:
-				result[k] = self.generators[k].first()
+				v = self.generators[k].first()
+			if Omitted.is_omitted(v) is not True:
+				result[k] = v
 		return result
 
 	def __iter__(self):
@@ -134,7 +131,7 @@ class ObjectValueGenerator:
 
 	def __next__(self):
 		result = self.next()
-		if isempty(result):
+		if Empty.isempty(result):
 			raise StopIteration()
 		s = json.dumps(result, sort_keys=True)
 		if s in self.seen:
@@ -145,7 +142,7 @@ class ObjectValueGenerator:
 
 class ArrayGenerator:
 	def _create_generator(self, field_name, definition, vector):
-		generator = _Empty()
+		generator = Empty()
 		if definition.data_type == DataType.Object:
 			generator = ObjectValueGenerator(field_name, definition, vector)
 		elif definition.data_type == DataType.Array:
@@ -172,7 +169,7 @@ class ArrayGenerator:
 		self.first_value = []
 		for g in self.generators:
 			v = g.first()
-			if isempty(v):
+			if Empty.isempty(v):
 				raise Config.exception_factory.create_internal_error(g.name, 'Missing values.')
 			self.first_value.append(v)
 			i = i + 1
@@ -181,12 +178,12 @@ class ArrayGenerator:
 
 	def _next(self):
 		result = []
-		variant = _Empty()
+		variant = Empty()
 		i = 0
 		for g in self.generators:
-			if isempty(variant) and i >= self.current_index:
+			if Empty.isempty(variant) and i >= self.current_index:
 				v = g.next()
-				if isempty(v):
+				if Empty.isempty(v):
 					result.append(self.first_value[i])
 				else:
 					result.append(v)
@@ -195,14 +192,14 @@ class ArrayGenerator:
 			else:
 				result.append(self.first_value[i])
 			i = i + 1
-		if isempty(variant):
-			self.first_value = _Empty()
+		if Empty.isempty(variant):
+			self.first_value = Empty()
 			return self.first_value
 		return result
 
 	def next(self):
 		result = self._next()
-		if isempty(result):
+		if Empty.isempty(result):
 			return result
 		s = json.dumps(result, sort_keys=True)
 		if s in self.seen:
@@ -215,7 +212,7 @@ class ArrayGenerator:
 
 	def __next__(self):
 		result = self.next()
-		if isempty(result):
+		if Empty.isempty(result):
 			raise StopIteration()
 		return result
 
