@@ -330,6 +330,7 @@ class ModelValidator:
 			field_definition_name = name
 			if field.definition_name is not None:
 				field_definition_name = field.definition_name
+			definition_names[name] = field_definition_name
 			field_definition = Definitions.Index.get(field_definition_name)
 			if field.required:
 				required.add(name)
@@ -339,8 +340,6 @@ class ModelValidator:
 				ignored.add(name)
 			if field.unvalidated:
 				unvalidated.add(name)
-			if field.definition_name:
-				definition_names[name] = field.definition_name
 			if field.output_name:
 				output_names[name] = field.output_name
 			if field.input_name:
